Struct hypixel_api::reply::StatusData
source · [−]pub struct StatusData { /* private fields */ }Expand description
The response data corresponding to this endpoint.
Implementations
sourceimpl StatusData
impl StatusData
sourcepub fn online(&self) -> bool
pub fn online(&self) -> bool
Returns true if the player is online.
Players have the option to hide this value in their settings:
false means either offline or online but hidden.
sourcepub fn game_type(&self) -> Option<&str>
pub fn game_type(&self) -> Option<&str>
Returns the type of game the player is currently playing, if present.
TODO: This will be changed into an enum