pub struct StatusReply { /* private fields */ }
A data structure that maps to this endpoint.

Response fields are captured in StatusData

Implementations

Returns whether the response was successful.

This should always return true. (not guaranteed though)

Methods from Deref<Target = StatusData>

Returns the player’s UUID.

Returns true if the player is online.

Players have the option to hide this value in their settings: false means either offline or online but hidden.

Returns the type of game the player is currently playing, if present.

TODO: This will be changed into an enum

Returns the mode of the game the player is playing, if present.

Returns the map the player is playing on, if present.