calculate_level

Function calculate_level 

pub fn calculate_level(exp: f64) -> f64
This function returns the level of a player calculated by the current experience gathered. Unlike exact_level, this function returns the largest integer smaller than the exact level (= floored).

The result cannot be smaller than 1.0 and negative experience results in 1.0.

Examples

           0 XP -> 1.0
        5000 XP -> 1.0
       10000 XP -> 2.0
       50000 XP -> 4.0
    79342431 XP -> 249.0